<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="71"/>
        <source>Deepin Home</source>
        <translation>Rumah Deepin</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Tunjuk tetingkap utama</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="89"/>
        <source>Communication</source>
        <translation>Komunikasi</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="92"/>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="333"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
</context>
</TS>